# rooibos.py

[![Build Status](https://travis-ci.org/squaresLab/rooibos.py.svg?branch=master)](https://travis-ci.org/squaresLab/rooibos.py)
[![PyPI version](https://badge.fury.io/py/rooibos.svg)](https://badge.fury.io/py/rooibos)
[![Python versions](https://img.shields.io/pypi/pyversions/rooibos.svg)](https://pypi.org/project/rooibos)

Python bindings for Rooibos
